==> aws-sdk-cpp-1.11.700-1-x86_64.pkg.tar.zst: usr/include/aws/connectparticipant/model/SendMessageResult.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/connectparticipant/ConnectParticipant_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace ConnectParticipant {
namespace Model {
class SendMessageResult {
 public:
  AWS_CONNECTPARTICIPANT_API SendMessageResult() = default;
  AWS_CONNECTPARTICIPANT_API SendMessageResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_CONNECTPARTICIPANT_API SendMessageResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The ID of the message.</p>
   */
  inline const Aws::String& GetId() const { return m_id; }
  template <typename IdT = Aws::String>
  void SetId(IdT&& value) {
    m_idHasBeenSet = true;
    m_id = std::forward<IdT>(value);
  }
  template <typename IdT = Aws::String>
  SendMessageResult& WithId(IdT&& value) {
    SetId(std::forward<IdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The time when the message was sent.</p> <p>It's specified in ISO 8601 format:
   * yyyy-MM-ddThh:mm:ss.SSSZ. For example, 2019-11-08T02:41:28.172Z.</p>
   */
  inline const Aws::String& GetAbsoluteTime() const { return m_absoluteTime; }
  template <typename AbsoluteTimeT = Aws::String>
  void SetAbsoluteTime(AbsoluteTimeT&& value) {
    m_absoluteTimeHasBeenSet = true;
    m_absoluteTime = std::forward<AbsoluteTimeT>(value);
  }
  template <typename AbsoluteTimeT = Aws::String>
  SendMessageResult& WithAbsoluteTime(AbsoluteTimeT&& value) {
    SetAbsoluteTime(std::forward<AbsoluteTimeT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  SendMessageResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_id;
  bool m_idHasBeenSet = false;

  Aws::String m_absoluteTime;
  bool m_absoluteTimeHasBeenSet = false;

  Aws::String m_requestId;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace ConnectParticipant
}  // namespace Aws

==> aws-sdk-cpp-1.11.705-1-x86_64.pkg.tar.zst: usr/include/aws/connectparticipant/model/SendMessageResult.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/connectparticipant/ConnectParticipant_EXPORTS.h>
#include <aws/connectparticipant/model/MessageProcessingMetadata.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace ConnectParticipant {
namespace Model {
class SendMessageResult {
 public:
  AWS_CONNECTPARTICIPANT_API SendMessageResult() = default;
  AWS_CONNECTPARTICIPANT_API SendMessageResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_CONNECTPARTICIPANT_API SendMessageResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The ID of the message.</p>
   */
  inline const Aws::String& GetId() const { return m_id; }
  template <typename IdT = Aws::String>
  void SetId(IdT&& value) {
    m_idHasBeenSet = true;
    m_id = std::forward<IdT>(value);
  }
  template <typename IdT = Aws::String>
  SendMessageResult& WithId(IdT&& value) {
    SetId(std::forward<IdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The time when the message was sent.</p> <p>It's specified in ISO 8601 format:
   * yyyy-MM-ddThh:mm:ss.SSSZ. For example, 2019-11-08T02:41:28.172Z.</p>
   */
  inline const Aws::String& GetAbsoluteTime() const { return m_absoluteTime; }
  template <typename AbsoluteTimeT = Aws::String>
  void SetAbsoluteTime(AbsoluteTimeT&& value) {
    m_absoluteTimeHasBeenSet = true;
    m_absoluteTime = std::forward<AbsoluteTimeT>(value);
  }
  template <typename AbsoluteTimeT = Aws::String>
  SendMessageResult& WithAbsoluteTime(AbsoluteTimeT&& value) {
    SetAbsoluteTime(std::forward<AbsoluteTimeT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Contains metadata for the message.</p>
   */
  inline const MessageProcessingMetadata& GetMessageMetadata() const { return m_messageMetadata; }
  template <typename MessageMetadataT = MessageProcessingMetadata>
  void SetMessageMetadata(MessageMetadataT&& value) {
    m_messageMetadataHasBeenSet = true;
    m_messageMetadata = std::forward<MessageMetadataT>(value);
  }
  template <typename MessageMetadataT = MessageProcessingMetadata>
  SendMessageResult& WithMessageMetadata(MessageMetadataT&& value) {
    SetMessageMetadata(std::forward<MessageMetadataT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  SendMessageResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_id;
  bool m_idHasBeenSet = false;

  Aws::String m_absoluteTime;
  bool m_absoluteTimeHasBeenSet = false;

  MessageProcessingMetadata m_messageMetadata;
  bool m_messageMetadataHasBeenSet = false;

  Aws::String m_requestId;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace ConnectParticipant
}  // namespace Aws
